.. pdblp documentation master file, created by
   sphinx-quickstart on Sun Feb  7 14:42:53 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

About pdblp
===========

pdblp attempts to provide a simple pandas wrapper around the Bloomberg Open
API, specifically to give access to historical market data and reference data.
This documentation provides a simple tutorial as well as a reference API.

.. toctree::
   :titlesonly:

   tutorial
   api

Installation
============
Please refer to the `README <https://github.com/matthewgilbert/pdblp/blob/master/README.md>`_
for installation instructions 


Contributions
=============
Contributions are welcome, the source repository is available
`here <https://github.com/matthewgilbert/pdblp>`_
